# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from abc import abstractmethod
from .x_file_picker3 import XFilePicker3 as XFilePicker3_f99e0d60

class FilePicker(XFilePicker3_f99e0d60):
    """
    Service Class

    A FilePicker.
    
    It is NOT recommended to cache a reference to a file picker instance. Due to restrictions by the underlying system there can be specific limitations possible. To overcome these problems it's recommended to create a new instance on demand.

    See Also:
        `API FilePicker <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1FilePicker.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.FilePicker'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createWithMode(self, Mode: int) -> None:
        """
        Provides the ability to choose between different custom templates that do extend the subset of common controls a FilePicker usually supports.
        
        Implementers may omit this interface if the FileOpen dialog doesn't support custom templates. In this case a createInstance will create an ordinary FileOpen dialog with only the common FilePicker elements. The client has to provide one of the specified constants in TemplateDescription.
        
        Notes for the implementation of a FileSave dialog: The implementation of a FileSave dialog should automatically check for existence of a file and issue a warning if a file with the same name already exist.
        
        Note that when creating a file picker, the top window is selected as the parent window for the file picker. Make sure that it does not get closed while opening the file picker, as there is a potential race.
        """
        ...

__all__ = ['FilePicker']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XScenario(XInterface_8f010a43):
    """
    provides access to the settings of a scenario sheet.

    See Also:
        `API XScenario <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenario.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XScenario'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XScenario'

    @abstractmethod
    def addRanges(self, aRanges: typing.Tuple[CellRangeAddress_ec450d43, ...]) -> None:
        """
        adds more ranges to the scenario.
        """
        ...
    @abstractmethod
    def apply(self) -> None:
        """
        applies the scenario.
        
        The contents of the scenario ranges are copied into the first non-scenario sheet which is in front of the sheet containing the scenario by itself.
        """
        ...
    @abstractmethod
    def getIsScenario(self) -> bool:
        """
        returns TRUE if the current object is a scenario.
        """
        ...
    @abstractmethod
    def getScenarioComment(self) -> str:
        """
        returns the comment for the scenario.
        """
        ...
    @abstractmethod
    def setScenarioComment(self, aScenarioComment: str) -> None:
        """
        sets a new comment for the scenario.
        """
        ...

__all__ = ['XScenario']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_bitmap import XBitmap as XBitmap_b1b70b7b
if typing.TYPE_CHECKING:
    from ..geometry.integer_point2_d import IntegerPoint2D as IntegerPoint2D_8f0dc2
    from ..geometry.integer_rectangle2_d import IntegerRectangle2D as IntegerRectangle2D_3c5c0f4d
    from .floating_point_bitmap_layout import FloatingPointBitmapLayout as FloatingPointBitmapLayout_c66812df

class XIeeeDoubleReadOnlyBitmap(XBitmap_b1b70b7b):
    """
    This is a specialized interface for bitmaps containing IEEE doubles for their color components.
    
    In contrast to XIeeeDoubleBitmap, this interface only permits read-only access.
    
    Use this interface for e.g. bitmaps that are calculated on-the-fly, or that are pure functional, and thus cannot be modified.
    
    If you get passed an instance of XHalfFloatReadOnlyBitmap that also supports the XVolatileBitmap interface, things become a bit more complicated. When reading data, one has to check for both VolatileContentDestroyedException and mismatching FloatingPointBitmapLayout return values. If either of them occurs, the whole bitmap read operation should be repeated.

    See Also:
        `API XIeeeDoubleReadOnlyBitmap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XIeeeDoubleReadOnlyBitmap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XIeeeDoubleReadOnlyBitmap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XIeeeDoubleReadOnlyBitmap'

    @abstractmethod
    def getData(self, bitmapLayout: FloatingPointBitmapLayout_c66812df, rect: IntegerRectangle2D_3c5c0f4d) -> typing.Tuple[float, ...]:
        """
        Query the raw data of this bitmap.
        
        Query the raw data of this bitmap, in the format as defined by getMemoryLayout(). With the given rectangle, a subset of the whole bitmap can be queried. When querying subsets of the bitmap, the same scanline padding takes place as when the whole bitmap is requested.
        
        Note that the bitmap memory layout might change for volatile bitmaps.

        * ``bitmapLayout`` is an out direction argument.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def getMemoryLayout(self) -> FloatingPointBitmapLayout_c66812df:
        """
        Query the memory layout for this bitmap.
        
        Please note that for volatile bitmaps, the memory layout might change between subsequent calls.
        """
        ...
    @abstractmethod
    def getPixel(self, bitmapLayout: FloatingPointBitmapLayout_c66812df, pos: IntegerPoint2D_8f0dc2) -> typing.Tuple[float, ...]:
        """
        Get a single pixel of the bitmap, returning its color value.
        
        Note that the bitmap memory layout might change for volatile bitmaps.

        * ``bitmapLayout`` is an out direction argument.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...

__all__ = ['XIeeeDoubleReadOnlyBitmap']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.xml.attribute import Attribute as Attribute
from ...lo.xml.attribute_container import AttributeContainer as AttributeContainer
from ...lo.xml.attribute_data import AttributeData as AttributeData
from ...lo.xml.export_filter import ExportFilter as ExportFilter
from ...lo.xml.fast_attribute import FastAttribute as FastAttribute
from ...lo.xml.import_filter import ImportFilter as ImportFilter
from ...lo.xml.namespace_container import NamespaceContainer as NamespaceContainer
from ...lo.xml.para_user_defined_attributes_supplier import ParaUserDefinedAttributesSupplier as ParaUserDefinedAttributesSupplier
from ...lo.xml.text_user_defined_attributes_supplier import TextUserDefinedAttributesSupplier as TextUserDefinedAttributesSupplier
from ...lo.xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier
from ...lo.xml.x_export_filter import XExportFilter as XExportFilter
from ...lo.xml.x_import_filter import XImportFilter as XImportFilter
from ...lo.xml.x_import_filter2 import XImportFilter2 as XImportFilter2
from ...lo.xml.xml_export_filter import XMLExportFilter as XMLExportFilter
from ...lo.xml.xml_import_filter import XMLImportFilter as XMLImportFilter



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.auth.authentication_failed_exception import AuthenticationFailedException as AuthenticationFailedException
from ...lo.auth.invalid_argument_exception import InvalidArgumentException as InvalidArgumentException
from ...lo.auth.invalid_context_exception import InvalidContextException as InvalidContextException
from ...lo.auth.invalid_credential_exception import InvalidCredentialException as InvalidCredentialException
from ...lo.auth.invalid_principal_exception import InvalidPrincipalException as InvalidPrincipalException
from ...lo.auth.persistence_failure_exception import PersistenceFailureException as PersistenceFailureException
from ...lo.auth.sso_manager_factory import SSOManagerFactory as SSOManagerFactory
from ...lo.auth.sso_password_cache import SSOPasswordCache as SSOPasswordCache
from ...lo.auth.unsupported_exception import UnsupportedException as UnsupportedException
from ...lo.auth.xsso_acceptor_context import XSSOAcceptorContext as XSSOAcceptorContext
from ...lo.auth.xsso_context import XSSOContext as XSSOContext
from ...lo.auth.xsso_initiator_context import XSSOInitiatorContext as XSSOInitiatorContext
from ...lo.auth.xsso_manager import XSSOManager as XSSOManager
from ...lo.auth.xsso_manager_factory import XSSOManagerFactory as XSSOManagerFactory
from ...lo.auth.xsso_password_cache import XSSOPasswordCache as XSSOPasswordCache



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924

class ErrorMessageDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    provides a dialog for displaying database related exceptions.
    
    If applications use any of the functionality provided in the modules com.sun.star.sdbc, com.sun.star.sdbcx and com.sun.star.sdb, they will - sooner or later - encounter com.sun.star.sdbc.SQLException 's. These exceptions can be chained, so the information wrapped in one single com.sun.star.sdbc.SQLException can be rather complex (e.g., every instance where such an exception is passing before it is finally caught, could append a com.sun.star.sdb.SQLContext to explain what it was doing), and they should be presented to the user in a consistent way. This can be reached by using this service.

    See Also:
        `API ErrorMessageDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1ErrorMessageDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.ErrorMessageDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, initialTitle: str, parentWindow: XWindow_713b0924, sqlException: object) -> None:
        """
        allows initializing the dialog
        
        You do not need to call the initialize method directly, instead you may use the createInstanceWithArguments method of your com.sun.star.lang.XMultiServiceFactory.
        
        You specify a parameter by passing one (or more) com.sun.star.beans.PropertyValue object(s) to the initialize method, where the Name field contains a string describing which aspect you want to affect, and the Value field containing a value. Imagine the initialization values, as if you use com.sun.star.beans\">XPropertySet.setPropertyValue() of the com.sun.star.beans.XPropertySet interface ... allowed parameters are
        """
        ...

__all__ = ['ErrorMessageDialog']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XRowLocate(XInterface_8f010a43):
    """
    is used to identify rows within a result set and to find rows by a bookmark.
    
    Bookmarks are only valid in the scope of the current result set and are not interchangeable between result sets. A bookmark could be a complex data structure, so it could not be compared in a safe way. Because of that, a provider has to implement the compare method for bookmarks.

    See Also:
        `API XRowLocate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XRowLocate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.XRowLocate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbcx.XRowLocate'

    @abstractmethod
    def compareBookmarks(self, first: object, second: object) -> int:
        """
        compares two bookmarks and returns an indication of their relative values.
        
        The bookmarks must apply to the same ResultSet. You cannot reliably compare bookmarks from different ResultSets, even if they were created from the same source or statement. A bookmark that is not valid, or incorrectly formed, will cause an exception.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getBookmark(self) -> object:
        """
        returns the bookmark of the current row of a result set.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def hasOrderedBookmarks(self) -> bool:
        """
        determines whether the bookmarks of a result set are ordered or not.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def hashBookmark(self, bookmark: object) -> int:
        """
        returns the hash value for a specified bookmark.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def moveRelativeToBookmark(self, bookmark: object, rows: int) -> bool:
        """
        moves the cursor a relative number of rows, either positive or negative starting at a given bookmark position.
        
        If the bookmark could not be located, a result set will be positioned after the last record. If the bookmark is invalid, or not generated by the current result set, then the behavior is not defined, even an abnormal termination is possible.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def moveToBookmark(self, bookmark: object) -> bool:
        """
        moves the cursor to the row identified by a valid bookmark.
        
        If the bookmark could not be located, a result set will be positioned after the last record. If the bookmark is invalid, or not generated by the current result set, then the behavior is not defined, even an abnormal termination is possible.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XRowLocate']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom.events
from __future__ import annotations
import typing
from abc import abstractmethod
from .xui_event import XUIEvent as XUIEvent_fa900d82
if typing.TYPE_CHECKING:
    from .x_event_target import XEventTarget as XEventTarget_36420f4b
    from ..views.x_abstract_view import XAbstractView as XAbstractView_35f90f4a

class XMouseEvent(XUIEvent_fa900d82):
    """

    See Also:
        `API XMouseEvent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1XMouseEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom.events'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.events.XMouseEvent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.events.XMouseEvent'

    @abstractmethod
    def getAltKey(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def getButton(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getClientX(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getClientY(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getCtrlKey(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def getMetaKey(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def getRelatedTarget(self) -> XEventTarget_36420f4b:
        """
        """
        ...
    @abstractmethod
    def getScreenX(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getScreenY(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getShiftKey(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def initMouseEvent(self, typeArg: str, canBubbleArg: bool, cancelableArg: bool, viewArg: XAbstractView_35f90f4a, detailArg: int, screenXArg: int, screenYArg: int, clientXArg: int, clientYArg: int, ctrlKeyArg: bool, altKeyArg: bool, shiftKeyArg: bool, metaKeyArg: bool, buttonArg: int, relatedTargetArg: XEventTarget_36420f4b) -> None:
        """
        """
        ...

__all__ = ['XMouseEvent']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.dom
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class DOMExceptionType(metaclass=UnoEnumMeta, type_name="com.sun.star.xml.dom.DOMExceptionType", name_space="com.sun.star.xml.dom"):
        """Dynamically created class that represents ``com.sun.star.xml.dom.DOMExceptionType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.xml.dom.DOMExceptionType import DOMSTRING_SIZE_ERR as D_O_M_EXCEPTION_TYPE_DOMSTRING_SIZE_ERR
        from com.sun.star.xml.dom.DOMExceptionType import HIERARCHY_REQUEST_ERR as D_O_M_EXCEPTION_TYPE_HIERARCHY_REQUEST_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INDEX_SIZE_ERR as D_O_M_EXCEPTION_TYPE_INDEX_SIZE_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INUSE_ATTRIBUTE_ERR as D_O_M_EXCEPTION_TYPE_INUSE_ATTRIBUTE_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INVALID_ACCESS_ERR as D_O_M_EXCEPTION_TYPE_INVALID_ACCESS_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INVALID_CHARACTER_ERR as D_O_M_EXCEPTION_TYPE_INVALID_CHARACTER_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INVALID_MODIFICATION_ERR as D_O_M_EXCEPTION_TYPE_INVALID_MODIFICATION_ERR
        from com.sun.star.xml.dom.DOMExceptionType import INVALID_STATE_ERR as D_O_M_EXCEPTION_TYPE_INVALID_STATE_ERR
        from com.sun.star.xml.dom.DOMExceptionType import NAMESPACE_ERR as D_O_M_EXCEPTION_TYPE_NAMESPACE_ERR
        from com.sun.star.xml.dom.DOMExceptionType import NOT_FOUND_ERR as D_O_M_EXCEPTION_TYPE_NOT_FOUND_ERR
        from com.sun.star.xml.dom.DOMExceptionType import NOT_SUPPORTED_ERR as D_O_M_EXCEPTION_TYPE_NOT_SUPPORTED_ERR
        from com.sun.star.xml.dom.DOMExceptionType import NO_DATA_ALLOWED_ERR as D_O_M_EXCEPTION_TYPE_NO_DATA_ALLOWED_ERR
        from com.sun.star.xml.dom.DOMExceptionType import NO_MODIFICATION_ALLOWED_ERR as D_O_M_EXCEPTION_TYPE_NO_MODIFICATION_ALLOWED_ERR
        from com.sun.star.xml.dom.DOMExceptionType import SYNTAX_ERR as D_O_M_EXCEPTION_TYPE_SYNTAX_ERR
        from com.sun.star.xml.dom.DOMExceptionType import WRONG_DOCUMENT_ERR as D_O_M_EXCEPTION_TYPE_WRONG_DOCUMENT_ERR

        class DOMExceptionType(uno.Enum):
            """
            Enum Class

            ENUM DOMExceptionType

            See Also:
                `API DOMExceptionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a31e3fb46d584de1cfc4b4c7640a41239>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.xml.dom.DOMExceptionType', value)

            __ooo_ns__: str = 'com.sun.star.xml.dom'
            __ooo_full_ns__: str = 'com.sun.star.xml.dom.DOMExceptionType'
            __ooo_type_name__: str = 'enum'

            DOMSTRING_SIZE_ERR = D_O_M_EXCEPTION_TYPE_DOMSTRING_SIZE_ERR
            """
            """
            HIERARCHY_REQUEST_ERR = D_O_M_EXCEPTION_TYPE_HIERARCHY_REQUEST_ERR
            """
            """
            INDEX_SIZE_ERR = D_O_M_EXCEPTION_TYPE_INDEX_SIZE_ERR
            """
            """
            INUSE_ATTRIBUTE_ERR = D_O_M_EXCEPTION_TYPE_INUSE_ATTRIBUTE_ERR
            """
            """
            INVALID_ACCESS_ERR = D_O_M_EXCEPTION_TYPE_INVALID_ACCESS_ERR
            """
            """
            INVALID_CHARACTER_ERR = D_O_M_EXCEPTION_TYPE_INVALID_CHARACTER_ERR
            """
            """
            INVALID_MODIFICATION_ERR = D_O_M_EXCEPTION_TYPE_INVALID_MODIFICATION_ERR
            """
            """
            INVALID_STATE_ERR = D_O_M_EXCEPTION_TYPE_INVALID_STATE_ERR
            """
            """
            NAMESPACE_ERR = D_O_M_EXCEPTION_TYPE_NAMESPACE_ERR
            """
            """
            NOT_FOUND_ERR = D_O_M_EXCEPTION_TYPE_NOT_FOUND_ERR
            """
            """
            NOT_SUPPORTED_ERR = D_O_M_EXCEPTION_TYPE_NOT_SUPPORTED_ERR
            """
            """
            NO_DATA_ALLOWED_ERR = D_O_M_EXCEPTION_TYPE_NO_DATA_ALLOWED_ERR
            """
            """
            NO_MODIFICATION_ALLOWED_ERR = D_O_M_EXCEPTION_TYPE_NO_MODIFICATION_ALLOWED_ERR
            """
            """
            SYNTAX_ERR = D_O_M_EXCEPTION_TYPE_SYNTAX_ERR
            """
            """
            WRONG_DOCUMENT_ERR = D_O_M_EXCEPTION_TYPE_WRONG_DOCUMENT_ERR
            """
            """
    else:
        # keep document generators happy
        from ....lo.xml.dom.dom_exception_type import DOMExceptionType as DOMExceptionType


__all__ = ['DOMExceptionType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .sort_field_type import SortFieldType as SortFieldType_bd500bf4


class SortField(object):
    """
    Struct Class

    describes a single field in a sort descriptor.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SortField <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SortField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.SortField'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.SortField'
    """Literal Constant ``com.sun.star.util.SortField``"""

    def __init__(self, Field: typing.Optional[int] = 0, SortAscending: typing.Optional[bool] = False, FieldType: typing.Optional[SortFieldType_bd500bf4] = SortFieldType_bd500bf4.AUTOMATIC) -> None:
        """
        Constructor

        Arguments:
            Field (int, optional): Field value.
            SortAscending (bool, optional): SortAscending value.
            FieldType (SortFieldType, optional): FieldType value.
        """
        super().__init__()

        if isinstance(Field, SortField):
            oth: SortField = Field
            self.Field = oth.Field
            self.SortAscending = oth.SortAscending
            self.FieldType = oth.FieldType
            return

        kargs = {
            "Field": Field,
            "SortAscending": SortAscending,
            "FieldType": FieldType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._field = kwargs["Field"]
        self._sort_ascending = kwargs["SortAscending"]
        self._field_type = kwargs["FieldType"]


    @property
    def Field(self) -> int:
        """
        index of the field in the table; 0-based.
        """
        return self._field

    @Field.setter
    def Field(self, value: int) -> None:
        self._field = value

    @property
    def SortAscending(self) -> bool:
        """
        TRUE if data are sorted in ascending order, FALSE if in descending order.
        """
        return self._sort_ascending

    @SortAscending.setter
    def SortAscending(self, value: bool) -> None:
        self._sort_ascending = value

    @property
    def FieldType(self) -> SortFieldType_bd500bf4:
        """
        type of contents in the field.
        """
        return self._field_type

    @FieldType.setter
    def FieldType(self, value: SortFieldType_bd500bf4) -> None:
        self._field_type = value


__all__ = ['SortField']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CalendarDisplayIndex(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.CalendarDisplayIndex", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.CalendarDisplayIndex``"""
        pass

    class CalendarDisplayIndexEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.CalendarDisplayIndex", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.CalendarDisplayIndex`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import CalendarDisplayIndex as CalendarDisplayIndex
    else:
        # keep document generators happy
        from ...lo.i18n.calendar_display_index import CalendarDisplayIndex as CalendarDisplayIndex

    class CalendarDisplayIndexEnum(IntEnum):
        """
        Enum of Const Class CalendarDisplayIndex

        Values to be passed to XCalendar.getDisplayName().
        
        **since**
        
            LibreOffice 3.5
        """
        AM_PM = CalendarDisplayIndex.AM_PM
        """
        name of an AM/PM value
        """
        DAY = CalendarDisplayIndex.DAY
        """
        name of a day of week
        """
        MONTH = CalendarDisplayIndex.MONTH
        """
        name of a month
        """
        YEAR = CalendarDisplayIndex.YEAR
        """
        name of a year (if used for a specific calendar)
        """
        ERA = CalendarDisplayIndex.ERA
        """
        name of an era, like BC/AD
        """
        GENITIVE_MONTH = CalendarDisplayIndex.GENITIVE_MONTH
        """
        name of a possessive genitive case month
        
        **since**
        
            LibreOffice 3.5
        """
        PARTITIVE_MONTH = CalendarDisplayIndex.PARTITIVE_MONTH
        """
        name of a partitive case month
        
        **since**
        
            LibreOffice 3.5
        """

__all__ = ['CalendarDisplayIndex', 'CalendarDisplayIndexEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .solver_constraint_operator import SolverConstraintOperator as SolverConstraintOperator_6e4a110d
from ..table.cell_address import CellAddress as CellAddress_ae5f0b56


class SolverConstraint(object):
    """
    Struct Class

    is used to specify a constraint for a solver model.

    See Also:
        `API SolverConstraint <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1SolverConstraint.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SolverConstraint'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.SolverConstraint'
    """Literal Constant ``com.sun.star.sheet.SolverConstraint``"""

    def __init__(self, Left: typing.Optional[CellAddress_ae5f0b56] = UNO_NONE, Operator: typing.Optional[SolverConstraintOperator_6e4a110d] = SolverConstraintOperator_6e4a110d.LESS_EQUAL, Right: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Left (CellAddress, optional): Left value.
            Operator (SolverConstraintOperator, optional): Operator value.
            Right (object, optional): Right value.
        """
        super().__init__()

        if isinstance(Left, SolverConstraint):
            oth: SolverConstraint = Left
            self.Left = oth.Left
            self.Operator = oth.Operator
            self.Right = oth.Right
            return

        kargs = {
            "Left": Left,
            "Operator": Operator,
            "Right": Right,
        }
        if kargs["Left"] is UNO_NONE:
            kargs["Left"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._left = kwargs["Left"]
        self._operator = kwargs["Operator"]
        self._right = kwargs["Right"]


    @property
    def Left(self) -> CellAddress_ae5f0b56:
        """
        The address of the cell that is constrained.
        """
        return self._left

    @Left.setter
    def Left(self, value: CellAddress_ae5f0b56) -> None:
        self._left = value

    @property
    def Operator(self) -> SolverConstraintOperator_6e4a110d:
        """
        The type of the constraint.
        """
        return self._operator

    @Operator.setter
    def Operator(self, value: SolverConstraintOperator_6e4a110d) -> None:
        self._operator = value

    @property
    def Right(self) -> object:
        """
        The comparison value, of type double or com.sun.star.table.CellAddress.
        """
        return self._right

    @Right.setter
    def Right(self, value: object) -> None:
        self._right = value


__all__ = ['SolverConstraint']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing


class ShadingPattern(object):
    """
    Const Class

    The ShadingPattern determines the background color pattern against which characters and graphics are displayed, typically in tables.
    
    The color can be no color or it can be a specific color with a transparency or pattern value.

    See Also:
        `API ShadingPattern <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.ShadingPattern'
    __ooo_type_name__: str = 'const'

    CLEAR = 0
    SOLID = 1
    PCT5 = 2
    PCT10 = 3
    PCT20 = 4
    PCT25 = 5
    PCT30 = 6
    PCT40 = 7
    PCT50 = 8
    PCT60 = 9
    PCT70 = 10
    PCT75 = 11
    PCT80 = 12
    PCT90 = 13
    HORZ_STRIPE = 14
    VERT_STRIPE = 15
    REVERSE_DIAG_STRIPE = 16
    DIAG_STRIPE = 17
    HORZ_CROSS = 18
    DIAG_CROSS = 19
    THIN_HORZ_STRIPE = 20
    THIN_VERT_STRIPE = 21
    THIN_REVERSE_DIAG_STRIPE = 22
    THIN_DIAG_STRIPE = 23
    THIN_HORZ_CROSS = 24
    THIN_DIAG_CROSS = 25
    UNUSED_1 = 26
    UNUSED_2 = 27
    UNUSED_3 = 28
    UNUSED_4 = 29
    UNUSED_5 = 30
    UNUSED_6 = 31
    UNUSED_7 = 32
    UNUSED_8 = 33
    UNUSED_9 = 34
    PCT2 = 35
    PCT7 = 36
    PCT12 = 37
    PCT15 = 38
    PCT17 = 39
    PCT22 = 40
    PCT27 = 41
    PCT32 = 42
    PCT35 = 43
    PCT37 = 44
    PCT42 = 45
    PCT45 = 46
    PCT47 = 47
    PCT52 = 48
    PCT55 = 49
    PCT57 = 50
    PCT62 = 51
    PCT65 = 52
    PCT67 = 53
    PCT72 = 54
    PCT77 = 55
    PCT82 = 56
    PCT85 = 57
    PCT87 = 58
    PCT92 = 59
    PCT95 = 60
    PCT97 = 61
    NIL = 65535

__all__ = ['ShadingPattern']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
from abc import abstractmethod
from .x_forms_supplier import XFormsSupplier as XFormsSupplier_c8f90c6f

class XFormsSupplier2(XFormsSupplier_c8f90c6f):
    """
    extends the XFormsSupplier with convenience methods

    See Also:
        `API XFormsSupplier2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XFormsSupplier2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XFormsSupplier2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XFormsSupplier2'

    @abstractmethod
    def hasForms(self) -> bool:
        """
        determines whether there are currently forms available at all
        
        If you need read access to the forms collection, then you might check the existence of forms using hasForms(), and if it returns FALSE, you can do as if XFormsSupplier.getForms() would have returned an empty container.
        
        Semantically, hasForms() is equivalent to calling XElementAccess.hasElements() on the container returned by XFormsSupplier.getForms(). But when using the latter, the implementation is forced to create an empty container, which might be potentially expensive.
        """
        ...

__all__ = ['XFormsSupplier2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_image_producer import XImageProducer as XImageProducer_ba930bd3

class XImageConsumer(XInterface_8f010a43):
    """
    specifies a data sink for an image.
    
    An image consumer is a component which wants to display or just receive an image from an image producer.

    See Also:
        `API XImageConsumer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XImageConsumer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XImageConsumer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XImageConsumer'

    @abstractmethod
    def complete(self, Status: int, xProducer: XImageProducer_ba930bd3) -> None:
        """
        is called for the notification of the degree to which the image is delivered.
        
        The complete method is called when the image producer has finished delivering all of the pixels that the source image contains, or when a single frame of a multi-frame animation has been completed, or when an error in loading or producing the image has occurred. The image consumer should remove itself from the list of consumers registered with the image producer at this time, unless it is interested in successive frames.
        """
        ...
    @abstractmethod
    def init(self, Width: int, Height: int) -> None:
        """
        initializes the consumer with image dimensions.
        """
        ...
    @abstractmethod
    def setColorModel(self, BitCount: int, RGBAPal: uno.ByteSequence, RedMask: int, GreenMask: int, BlueMask: int, AlphaMask: int) -> None:
        """
        changes color model for next pixels typically called once after initialization.
        """
        ...
    @abstractmethod
    def setPixelsByBytes(self, nX: int, nY: int, nWidth: int, nHeight: int, aProducerData: uno.ByteSequence, nOffset: int, nScanSize: int) -> None:
        """
        delivers a chunk of pixels as long values.
        
        The pixels of the image are delivered using one or more calls to this method. Each call specifies the location and size of the rectangle of source pixels that are contained in the array of pixels. The specified color model object should be used to convert the pixels into their corresponding color and alpha components. Pixel (m,n) is stored in the pixels array at index (n * nScanSize
        """
        ...
    @abstractmethod
    def setPixelsByLongs(self, nX: int, nY: int, nWidth: int, nHeight: int, aProducerData: uno.ByteSequence, nOffset: int, nScanSize: int) -> None:
        """
        delivers a chunk of pixels as byte values.
        
        The pixels of the image are delivered using one or more calls to this method. Each call specifies the location and size of the rectangle of source pixels that are contained in the array of pixels. The specified color model object should be used to convert the pixels into their corresponding color and alpha components. Pixel (m,n) is stored in the pixels array at index (n * nScanSize
        """
        ...

__all__ = ['XImageConsumer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.formula
from __future__ import annotations
from abc import abstractproperty, ABC

class FormulaProperties(ABC):
    """
    Service Class

    The formula properties provide access to the properties of a formula in a formula generator.
    
    **since**
    
        OOo 3.4

    See Also:
        `API FormulaProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1formula_1_1FormulaProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.formula'
    __ooo_full_ns__: str = 'com.sun.star.formula.FormulaProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Alignment(self) -> int:
        """
        contains the alignment of the formula.
        """
        ...

    @abstractproperty
    def BaseFontHeight(self) -> int:
        """
        contains the base font height in point the formula will be formatted in.
        
        All properties containing relative values are related to this value.
        """
        ...

    @abstractproperty
    def BaseLine(self) -> int:
        """
        contains the baselines offset in respect to the top of the formula rectangle
        
        **since**
        
            OOo 3.4
        """
        ...

    @abstractproperty
    def BottomMargin(self) -> int:
        """
        contains the metric value of the bottom margin of the formula.
        """
        ...

    @abstractproperty
    def CustomFontNameFixed(self) -> str:
        """
        customized name for fixed font.
        """
        ...

    @abstractproperty
    def CustomFontNameSans(self) -> str:
        """
        customized name for sans serif font
        """
        ...

    @abstractproperty
    def CustomFontNameSerif(self) -> str:
        """
        customized name for serif font
        """
        ...

    @abstractproperty
    def FontFixedIsBold(self) -> bool:
        """
        determines if the customized fixed font is bold.
        """
        ...

    @abstractproperty
    def FontFixedIsItalic(self) -> bool:
        """
        determines if the customized fixed font is italic.
        """
        ...

    @abstractproperty
    def FontFunctionsIsBold(self) -> bool:
        """
        determines if the font that is used to display functions is bold.
        """
        ...

    @abstractproperty
    def FontFunctionsIsItalic(self) -> bool:
        """
        determines if the font that is used to display functions is italic.
        """
        ...

    @abstractproperty
    def FontNameFunctions(self) -> str:
        """
        contains the name of the font that is used to display functions contained in the formula.
        """
        ...

    @abstractproperty
    def FontNameNumbers(self) -> str:
        """
        contains the name of the font that is used to display numbers contained in the formula.
        """
        ...

    @abstractproperty
    def FontNameText(self) -> str:
        """
        contains the name of the font that is used to display text contained in the formula.
        """
        ...

    @abstractproperty
    def FontNameVariables(self) -> str:
        """
        contains the name of the font that is used to display variables contained in the formula.
        """
        ...

    @abstractproperty
    def FontNumbersIsBold(self) -> bool:
        """
        determines if the font that is used to display numbers is bold.
        """
        ...

    @abstractproperty
    def FontNumbersIsItalic(self) -> bool:
        """
        determines if the font that is used to display numbers is italic.
        """
        ...

    @abstractproperty
    def FontSansIsBold(self) -> bool:
        """
        determines if the customized sans serif font is bold.
        """
        ...

    @abstractproperty
    def FontSansIsItalic(self) -> bool:
        """
        determines if the customized sans serif font is italic.
        """
        ...

    @abstractproperty
    def FontSerifIsBold(self) -> bool:
        """
        determines if the customized serif font is bold.
        """
        ...

    @abstractproperty
    def FontSerifIsItalic(self) -> bool:
        """
        determines if the customized serif font is italic.
        """
        ...

    @abstractproperty
    def FontTextIsBold(self) -> bool:
        """
        determines if the font that is used to display text is bold.
        """
        ...

    @abstractproperty
    def FontTextIsItalic(self) -> bool:
        """
        determines if the font that is used to display text is italic.
        """
        ...

    @abstractproperty
    def FontVariablesIsBold(self) -> bool:
        """
        determines if the font that is used to display variables is bold.
        """
        ...

    @abstractproperty
    def FontVariablesIsItalic(self) -> bool:
        """
        determines if the font that is used to display variables is italic.
        """
        ...

    @abstractproperty
    def Formula(self) -> str:
        """
        contains the command string of the formula
        """
        ...

    @abstractproperty
    def IsScaleAllBrackets(self) -> bool:
        """
        decides if all brackets (even those without \"left\"/\"right\" modifier) are scaled.
        """
        ...

    @abstractproperty
    def IsTextMode(self) -> bool:
        """
        switches into text mode.
        
        This is a mode where formulas are displayed the same height as a line of text.
        """
        ...

    @abstractproperty
    def LeftMargin(self) -> int:
        """
        contains the metric value of the left margin of the formula.
        """
        ...

    @abstractproperty
    def RelativeBracketDistance(self) -> int:
        """
        contains the relative distance of brackets.
        """
        ...

    @abstractproperty
    def RelativeBracketExcessSize(self) -> int:
        """
        contains the relative excess size of brackets.
        """
        ...

    @abstractproperty
    def RelativeFontHeightFunctions(self) -> int:
        """
        contains the relative height of the font for functions.
        
        The values unit is percent of the com.sun.star.formula.FormulaProperties.BaseFontHeight
        """
        ...

    @abstractproperty
    def RelativeFontHeightIndices(self) -> int:
        """
        contains the relative height of the font for indices.
        
        The values unit is percent of the com.sun.star.formula.FormulaProperties.BaseFontHeight
        """
        ...

    @abstractproperty
    def RelativeFontHeightLimits(self) -> int:
        """
        contains the relative height of the font for limits.
        
        The values unit is percent of the com.sun.star.formula.FormulaProperties.BaseFontHeight
        """
        ...

    @abstractproperty
    def RelativeFontHeightOperators(self) -> int:
        """
        contains the relative height of the font for operators.
        
        The values unit is percent of the com.sun.star.formula.FormulaProperties.BaseFontHeight
        """
        ...

    @abstractproperty
    def RelativeFontHeightText(self) -> int:
        """
        contains the relative height of the font for text.
        
        The values unit is percent of the com.sun.star.formula.FormulaProperties.BaseFontHeight
        """
        ...

    @abstractproperty
    def RelativeFractionBarExcessLength(self) -> int:
        """
        contains the relative excess length of a fraction bar.
        """
        ...

    @abstractproperty
    def RelativeFractionBarLineWeight(self) -> int:
        """
        contains the relative line weight of a fraction bar.
        """
        ...

    @abstractproperty
    def RelativeFractionDenominatorDepth(self) -> int:
        """
        contains the relative depth of the denominator of a fraction
        """
        ...

    @abstractproperty
    def RelativeFractionNumeratorHeight(self) -> int:
        """
        contains the relative height of the numerator of a fraction.
        """
        ...

    @abstractproperty
    def RelativeIndexSubscript(self) -> int:
        """
        contains the relative superscript of indices.
        """
        ...

    @abstractproperty
    def RelativeIndexSuperscript(self) -> int:
        """
        contains the relative subscript of indices.
        """
        ...

    @abstractproperty
    def RelativeLineSpacing(self) -> int:
        """
        contains the relative line spacing.
        """
        ...

    @abstractproperty
    def RelativeLowerLimitDistance(self) -> int:
        """
        contains the relative distance of lower limits.
        """
        ...

    @abstractproperty
    def RelativeMatrixColumnSpacing(self) -> int:
        """
        contains the relative column spacing of matrices.
        """
        ...

    @abstractproperty
    def RelativeMatrixLineSpacing(self) -> int:
        """
        contains the relative line spacing of matrices.
        """
        ...

    @abstractproperty
    def RelativeOperatorExcessSize(self) -> int:
        """
        contains the relative excess of operators.
        """
        ...

    @abstractproperty
    def RelativeOperatorSpacing(self) -> int:
        """
        contains the relative spacing of operators.
        """
        ...

    @abstractproperty
    def RelativeRootSpacing(self) -> int:
        """
        contains the relative root spacing
        """
        ...

    @abstractproperty
    def RelativeScaleBracketExcessSize(self) -> int:
        """
        contains the relative scaling of the bracket excess.
        """
        ...

    @abstractproperty
    def RelativeSpacing(self) -> int:
        """
        contains the relative spacing.
        """
        ...

    @abstractproperty
    def RelativeSymbolMinimumHeight(self) -> int:
        """
        contains the relative minimum height of the formula.
        """
        ...

    @abstractproperty
    def RelativeSymbolPrimaryHeight(self) -> int:
        """
        contains the relative primary height of symbols.
        """
        ...

    @abstractproperty
    def RelativeUpperLimitDistance(self) -> int:
        """
        contains the relative distance of upper limits
        """
        ...

    @abstractproperty
    def RightMargin(self) -> int:
        """
        contains the metric value of the right margin of the formula.
        """
        ...

    @abstractproperty
    def TopMargin(self) -> int:
        """
        contains the metric value of the top margin of the formula.
        """
        ...


__all__ = ['FormulaProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba


class VBAEventId(object):
    """
    Const Class

    Constants used to identify VBA document events.
    
    If one of these events is fired, a specific VBA macro in a specific document code module will be executed.
    
    Each event expects some specific arguments to be passed to XVBAEventProcessor.processVbaEvent().

    See Also:
        `API VBAEventId <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAEventId.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.vba'
    __ooo_full_ns__: str = 'com.sun.star.script.vba.VBAEventId'
    __ooo_type_name__: str = 'const'

    NO_EVENT = -1
    """
    An identifier not corresponding to any VBA document event.
    """
    AUTO_NEW = 1
    """
    New document opened from template.
    
    No arguments.
    """
    AUTO_OPEN = 2
    """
    Document opened (loaded).
    
    No arguments.
    """
    AUTO_CLOSE = 3
    """
    Document about to be closed.
    
    No arguments.
    """
    AUTO_EXEC = 4
    """
    Application start.
    
    No arguments.
    """
    AUTO_EXIT = 5
    """
    Application exit.
    
    No arguments.
    """
    DOCUMENT_NEW = 1001
    """
    New text document opened from template.
    
    No arguments.
    """
    DOCUMENT_OPEN = 1002
    """
    Text document opened (loaded).
    
    No arguments.
    """
    DOCUMENT_CLOSE = 1003
    """
    Document about to be closed.
    
    No arguments.
    """
    WORKBOOK_ACTIVATE = 2001
    """
    Document activated.
    
    No arguments.
    """
    WORKBOOK_DEACTIVATE = 2002
    """
    Document deactivated.
    
    No arguments.
    """
    WORKBOOK_OPEN = 2003
    """
    Document opened (loaded).
    
    No arguments.
    """
    WORKBOOK_BEFORECLOSE = 2004
    """
    Document about to be closed.
    
    Arguments: [out] boolean bCancel.
    """
    WORKBOOK_BEFOREPRINT = 2005
    """
    Document about to be printed.
    
    Arguments: [out] boolean bCancel.
    """
    WORKBOOK_BEFORESAVE = 2006
    """
    Document about to be saved.
    
    Arguments: boolean bSaveAs, [out] boolean bCancel.
    """
    WORKBOOK_AFTERSAVE = 2007
    """
    Document has been saved.
    
    Arguments: boolean bSuccess.
    """
    WORKBOOK_NEWSHEET = 2008
    """
    New sheet inserted.
    
    Arguments: short nSheet.
    """
    WORKBOOK_WINDOWACTIVATE = 2009
    """
    Document window has been activated.
    
    Arguments: XController aController.
    """
    WORKBOOK_WINDOWDEACTIVATE = 2010
    """
    Document window has been deactivated.
    
    Arguments: XController aController.
    """
    WORKBOOK_WINDOWRESIZE = 2011
    """
    Document window has been resized.
    
    Arguments: XController aController.
    """
    WORKSHEET_ACTIVATE = 2101
    """
    Worksheet has been activated (made visible).
    
    Arguments: short nSheet.
    """
    WORKSHEET_DEACTIVATE = 2102
    """
    Worksheet has been activated (made visible).
    
    Arguments: short nSheet.
    """
    WORKSHEET_BEFOREDOUBLECLICK = 2103
    """
    Double click in the sheet.
    
    Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
    """
    WORKSHEET_BEFORERIGHTCLICK = 2104
    """
    Right click in the sheet.
    
    Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
    """
    WORKSHEET_CALCULATE = 2105
    """
    Cells in sheet have been recalculated.
    
    Arguments: short nSheet.
    """
    WORKSHEET_CHANGE = 2106
    """
    Cells in sheet have been changed.
    
    Arguments: XRange/XSheetCellRangeContainer aRange.
    """
    WORKSHEET_SELECTIONCHANGE = 2107
    """
    Selection in sheet has been changed.
    
    Arguments: XRange/XSheetCellRangeContainer aRange.
    """
    WORKSHEET_FOLLOWHYPERLINK = 2108
    """
    Hyperlink has been clicked.
    
    Arguments: XCell aCell.
    """
    USERDEFINED_START = 1000000
    """
    Implementations are allowed to use identifiers above this value for any internal purpose.
    """

__all__ = ['VBAEventId']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .url import URL as URL_57ad07b9

class XURLTransformer(XInterface_8f010a43):
    """
    supports parsing and assembling of URLs

    See Also:
        `API XURLTransformer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XURLTransformer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XURLTransformer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XURLTransformer'

    @abstractmethod
    def assemble(self, aURL: object) -> bool:
        """
        assembles the parts of the URL specified by aURL and stores it into URL.Complete
        """
        ...
    @abstractmethod
    def getPresentation(self, aURL: URL_57ad07b9, bWithPassword: bool) -> str:
        """
        returns a representation of the URL for UI purposes only
        
        Sometimes it can be useful to show a URL on an user interface in a more \"human readable\" form. Such URL can't be used on any API call, but make it easier for the user to understand it.
        """
        ...
    @abstractmethod
    def parseSmart(self, aURL: object, sSmartProtocol: str) -> bool:
        """
        parses the string in URL.Complete, which may contain a syntactically complete URL or is specified by the provided protocol
        
        The implementation can use smart functions to correct or interpret URL.Complete if it is not a syntactically complete URL. The parts of the URL are stored in the other fields of aURL.
        """
        ...
    @abstractmethod
    def parseStrict(self, aURL: object) -> bool:
        """
        parses the string in URL.Complete which should contain a syntactically complete URL.
        
        The implementation is allowed to correct minor failures in URL.Complete if the meaning of the URL remain unchanged. Parts of the URL are stored in the other fields of aURL.
        """
        ...

__all__ = ['XURLTransformer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ListAction(object):
    """
    Struct Class

    This struct contains information needed in the notifications of a XDynamicResultSet.

    See Also:
        `API ListAction <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ListAction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ListAction'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.ListAction'
    """Literal Constant ``com.sun.star.ucb.ListAction``"""

    def __init__(self, Position: typing.Optional[int] = 0, Count: typing.Optional[int] = 0, ListActionType: typing.Optional[int] = 0, ActionInfo: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Position (int, optional): Position value.
            Count (int, optional): Count value.
            ListActionType (int, optional): ListActionType value.
            ActionInfo (object, optional): ActionInfo value.
        """
        super().__init__()

        if isinstance(Position, ListAction):
            oth: ListAction = Position
            self.Position = oth.Position
            self.Count = oth.Count
            self.ListActionType = oth.ListActionType
            self.ActionInfo = oth.ActionInfo
            return

        kargs = {
            "Position": Position,
            "Count": Count,
            "ListActionType": ListActionType,
            "ActionInfo": ActionInfo,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._count = kwargs["Count"]
        self._list_action_type = kwargs["ListActionType"]
        self._action_info = kwargs["ActionInfo"]


    @property
    def Position(self) -> int:
        """
        The position where something has happened (index begins with 1 as usual with JDBC ).
        
        Its value does not necessary indicate the new position in the new com.sun.star.sdbc.XResultSet, but a position while doing the changes step by step beginning with the old com.sun.star.sdbc.XResultSet.
        """
        return self._position

    @Position.setter
    def Position(self, value: int) -> None:
        self._position = value

    @property
    def Count(self) -> int:
        """
        The count of involved rows.
        """
        return self._count

    @Count.setter
    def Count(self, value: int) -> None:
        self._count = value

    @property
    def ListActionType(self) -> int:
        """
        specifies the kind of modification happened to all assigned rows.
        
        The value of the other members of this struct depend on the value of this member:
        """
        return self._list_action_type

    @ListActionType.setter
    def ListActionType(self, value: int) -> None:
        self._list_action_type = value

    @property
    def ActionInfo(self) -> object:
        """
        depending on the content of ListAction.ListActionType the ListAction.ActionInfo could contain additional information about the changes happened (see table above).
        """
        return self._action_info

    @ActionInfo.setter
    def ActionInfo(self, value: object) -> None:
        self._action_info = value


__all__ = ['ListAction']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_extended_component import XAccessibleExtendedComponent as XAccessibleExtendedComponent_539d159a

class AccessibleShape(XAccessible_1cbc0eb6, XAccessibleContext_8eae119b, XAccessibleExtendedComponent_539d159a):
    """
    Service Class

    The AccessibleShape service is implemented by UNO shapes to provide accessibility information that describe the shape's features.
    
    A UNO shape is any object that implements the com.sun.star.drawing.XShape interface.
    
    The content of a draw page is modelled as tree of accessible shapes and accessible text paragraphs. The root of this (sub-)tree is the accessible draw document view. An accessible shape implements either this service or one of the \"derived\" services AccessibleGraphicShape or AccessibleOLEShape. See the section Children in the description of the com.sun.star.accessibility.XAccessibleContext interface support for more details.
    
    There are two services that extend this one: the AccessibleGraphicShape and the AccessibleOLEShape services provide additional interfaces. See there for details.
    
    A shape object is either fully or partially visible on the screen or has set the com.sun.star.accessibility.AccessibleStateType.DEFUNC state to indicate that it is no longer actively supported by its parent.
    
    Each shape object that has not set the DEFUNC state has a valid parent. That is either the containing draw page or a group shape or a 3D scene object.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleShape'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty, ABC

class FootnoteSettings(ABC):
    """
    Service Class

    provides access to the settings of footnotes or endnotes in a (text) document.
    
    **since**
    
        OOo 2.0

    See Also:
        `API FootnoteSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1FootnoteSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.FootnoteSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AnchorCharStyleName(self) -> str:
        """
        contains the name of the character style that is used for footnote/endnote anchor in the text.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def BeginNotice(self) -> str:
        """
        contains the string at the restart of the footnote text after a break.
        
        For footnotes only.
        """
        ...

    @abstractproperty
    def CharStyleName(self) -> str:
        """
        contains the name of the character style that is used for the label in front of the footnote/endnote text.
        """
        ...

    @abstractproperty
    def EndNotice(self) -> str:
        """
        contains the string at the end of a footnote part in front of a break.
        
        For footnotes only.
        """
        ...

    @abstractproperty
    def FootnoteCounting(self) -> int:
        """
        contains the type of the counting of the footnote numbers.
        
        For footnotes only.
        """
        ...

    @abstractproperty
    def NumberingType(self) -> int:
        """
        contains the numbering type for the numbering of the footnotes/endnotes.
        """
        ...

    @abstractproperty
    def PageStyleName(self) -> str:
        """
        contains the page style that is used for the page that contains the footnote/endnote texts
        """
        ...

    @abstractproperty
    def ParaStyleName(self) -> str:
        """
        contains the paragraph style that is used for the footnote/endnote text.
        """
        ...

    @abstractproperty
    def PositionEndOfDoc(self) -> bool:
        """
        If TRUE, the footnote text is shown at the end of the document.
        
        For footnotes only.
        """
        ...

    @abstractproperty
    def Prefix(self) -> str:
        """
        contains the prefix for the footnote/endnote symbol.
        """
        ...

    @abstractproperty
    def StartAt(self) -> int:
        """
        contains the first number of the automatic numbering of footnotes/endnotes.
        """
        ...

    @abstractproperty
    def Suffix(self) -> str:
        """
        contains the suffix for the footnote/endnote symbol.
        """
        ...


__all__ = ['FootnoteSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .open_command_argument import OpenCommandArgument as OpenCommandArgument_fb0a0dd6
from ..beans.property import Property as Property_8f4e0a76
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .numbered_sorting_info import NumberedSortingInfo as NumberedSortingInfo_fd0e0de6


class OpenCommandArgument2(OpenCommandArgument_fb0a0dd6):
    """
    Struct Class

    The argument for commands like \"open\", \"update\", and \"synchronize\".
    
    This struct extends the original OpenCommandArgument, which must not be changed for compatibility reasons.

    See Also:
        `API OpenCommandArgument2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.OpenCommandArgument2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.OpenCommandArgument2'
    """Literal Constant ``com.sun.star.ucb.OpenCommandArgument2``"""

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = (), Mode: typing.Optional[int] = 0, Priority: typing.Optional[int] = 0, Sink: typing.Optional[XInterface_8f010a43] = None, SortingInfo: typing.Optional[typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Mode (int, optional): Mode value.
            Priority (int, optional): Priority value.
            Sink (XInterface, optional): Sink value.
            SortingInfo (typing.Tuple[NumberedSortingInfo, ...], optional): SortingInfo value.
        """

        if isinstance(Properties, OpenCommandArgument2):
            oth: OpenCommandArgument2 = Properties
            self.Properties = oth.Properties
            self.Mode = oth.Mode
            self.Priority = oth.Priority
            self.Sink = oth.Sink
            self.SortingInfo = oth.SortingInfo
            return

        kargs = {
            "Properties": Properties,
            "Mode": Mode,
            "Priority": Priority,
            "Sink": Sink,
            "SortingInfo": SortingInfo,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._sorting_info = kwargs["SortingInfo"]
        inst_keys = ('SortingInfo',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def SortingInfo(self) -> typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]:
        """
        The sort criteria for the rows of the returned ContentResultSet.
        
        The result set implementation may ignore this parameter, if it cannot sort the data by the given criteria in an efficient way (i.e. directly using the underlying data source -> SQL-database -> ORDER BY).
        """
        return self._sorting_info

    @SortingInfo.setter
    def SortingInfo(self, value: typing.Tuple[NumberedSortingInfo_fd0e0de6, ...]) -> None:
        self._sorting_info = value


__all__ = ['OpenCommandArgument2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod, ABC

class XDateCategories(ABC):
    """
    Allows to set date values as categories.
    
    Can be obtained from interface XChartDocument via method getData().
    
    **since**
    
        OOo 3.4

    See Also:
        `API XDateCategories <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XDateCategories.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XDateCategories'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XDateCategories'

    @abstractmethod
    def getDateCategories(self) -> typing.Tuple[float, ...]:
        """
        retrieves the date values if the category x-axis id a date axis
        """
        ...
    @abstractmethod
    def setDateCategories(self, rDates: typing.Tuple[float, ...]) -> None:
        """
        sets dates as categories
        """
        ...

__all__ = ['XDateCategories']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TransliterationModulesNew(metaclass=UnoEnumMeta, type_name="com.sun.star.i18n.TransliterationModulesNew", name_space="com.sun.star.i18n"):
        """Dynamically created class that represents ``com.sun.star.i18n.TransliterationModulesNew`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumHangul_ko as TRANSLITERATION_MODULES_NEW_CharToNumHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_ko as TRANSLITERATION_MODULES_NEW_CharToNumLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_zh_CN as TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumLower_zh_TW as TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_ko as TRANSLITERATION_MODULES_NEW_CharToNumUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_zh_CN as TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import CharToNumUpper_zh_TW as TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import END_OF_MODULE as TRANSLITERATION_MODULES_NEW_END_OF_MODULE
        from com.sun.star.i18n.TransliterationModulesNew import FULLWIDTH_HALFWIDTH as TRANSLITERATION_MODULES_NEW_FULLWIDTH_HALFWIDTH
        from com.sun.star.i18n.TransliterationModulesNew import HALFWIDTH_FULLWIDTH as TRANSLITERATION_MODULES_NEW_HALFWIDTH_FULLWIDTH
        from com.sun.star.i18n.TransliterationModulesNew import HIRAGANA_KATAKANA as TRANSLITERATION_MODULES_NEW_HIRAGANA_KATAKANA
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_CASE as TRANSLITERATION_MODULES_NEW_IGNORE_CASE
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_KANA as TRANSLITERATION_MODULES_NEW_IGNORE_KANA
        from com.sun.star.i18n.TransliterationModulesNew import IGNORE_WIDTH as TRANSLITERATION_MODULES_NEW_IGNORE_WIDTH
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreBaFa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreBaFa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreHyuByu_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreHyuByu_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreIandEfollowedByYa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreIandEfollowedByYa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreIterationMark_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreIterationMark_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreKiKuFollowedBySa_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreKiKuFollowedBySa_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreMiddleDot_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreMiddleDot_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreMinusSign_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreMinusSign_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreProlongedSoundMark_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreProlongedSoundMark_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSeZe_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSeZe_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSeparator_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSeparator_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSize_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSize_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreSpace_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreSpace_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTiJi_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTiJi_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTraditionalKana_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKana_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreTraditionalKanji_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKanji_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import IgnoreZiZu_ja_JP as TRANSLITERATION_MODULES_NEW_IgnoreZiZu_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import KATAKANA_HIRAGANA as TRANSLITERATION_MODULES_NEW_KATAKANA_HIRAGANA
        from com.sun.star.i18n.TransliterationModulesNew import LOWERCASE_UPPERCASE as TRANSLITERATION_MODULES_NEW_LOWERCASE_UPPERCASE
        from com.sun.star.i18n.TransliterationModulesNew import LargeToSmall_ja_JP as TRANSLITERATION_MODULES_NEW_LargeToSmall_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharFullwidth as TRANSLITERATION_MODULES_NEW_NumToCharFullwidth
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharHangul_ko as TRANSLITERATION_MODULES_NEW_NumToCharHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharKanjiShort_ja_JP as TRANSLITERATION_MODULES_NEW_NumToCharKanjiShort_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_ko as TRANSLITERATION_MODULES_NEW_NumToCharLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_zh_CN as TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharLower_zh_TW as TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_ko as TRANSLITERATION_MODULES_NEW_NumToCharUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_zh_CN as TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToCharUpper_zh_TW as TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalHangul_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalLower_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextFormalUpper_ko as TRANSLITERATION_MODULES_NEW_NumToTextFormalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalHangul_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalLower_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextInformalUpper_ko as TRANSLITERATION_MODULES_NEW_NumToTextInformalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextLower_zh_CN as TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextLower_zh_TW as TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextUpper_zh_CN as TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import NumToTextUpper_zh_TW as TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import SmallToLarge_ja_JP as TRANSLITERATION_MODULES_NEW_SmallToLarge_ja_JP
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalHangul_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalLower_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumFormalUpper_ko as TRANSLITERATION_MODULES_NEW_TextToNumFormalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalHangul_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalHangul_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalLower_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalLower_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumInformalUpper_ko as TRANSLITERATION_MODULES_NEW_TextToNumInformalUpper_ko
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumLower_zh_CN as TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumLower_zh_TW as TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumUpper_zh_CN as TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_CN
        from com.sun.star.i18n.TransliterationModulesNew import TextToNumUpper_zh_TW as TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_TW
        from com.sun.star.i18n.TransliterationModulesNew import UPPERCASE_LOWERCASE as TRANSLITERATION_MODULES_NEW_UPPERCASE_LOWERCASE

        class TransliterationModulesNew(uno.Enum):
            """
            Enum Class


            See Also:
                `API TransliterationModulesNew <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.i18n.TransliterationModulesNew', value)

            __ooo_ns__: str = 'com.sun.star.i18n'
            __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModulesNew'
            __ooo_type_name__: str = 'enum'

            CharToNumHangul_ko = TRANSLITERATION_MODULES_NEW_CharToNumHangul_ko
            """
            Transliterate a Korean Hangul number string to ASCII number string.
            """
            CharToNumLower_ko = TRANSLITERATION_MODULES_NEW_CharToNumLower_ko
            """
            Transliterate a Korean Hanja lower case number string to ASCII number string.
            """
            CharToNumLower_zh_CN = TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_CN
            """
            Transliterate a Simplified Chinese lower case number string to ASCII number string.
            """
            CharToNumLower_zh_TW = TRANSLITERATION_MODULES_NEW_CharToNumLower_zh_TW
            """
            Transliterate a Traditional Chinese lower case number string to ASCII number string.
            """
            CharToNumUpper_ko = TRANSLITERATION_MODULES_NEW_CharToNumUpper_ko
            """
            Transliterate a Korean Hanja upper case number string to ASCII number string.
            """
            CharToNumUpper_zh_CN = TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_CN
            """
            Transliterate a Simplified Chinese upper case number string to ASCII number string.
            """
            CharToNumUpper_zh_TW = TRANSLITERATION_MODULES_NEW_CharToNumUpper_zh_TW
            """
            Transliterate a Traditional Chinese upper case number string to ASCII number string.
            """
            END_OF_MODULE = TRANSLITERATION_MODULES_NEW_END_OF_MODULE
            """
            """
            FULLWIDTH_HALFWIDTH = TRANSLITERATION_MODULES_NEW_FULLWIDTH_HALFWIDTH
            """
            Transliterate a string from full width character to half width character.
            """
            HALFWIDTH_FULLWIDTH = TRANSLITERATION_MODULES_NEW_HALFWIDTH_FULLWIDTH
            """
            Transliterate a string from half width character to full width character.
            """
            HIRAGANA_KATAKANA = TRANSLITERATION_MODULES_NEW_HIRAGANA_KATAKANA
            """
            Transliterate a Japanese string from Hiragana to Katakana.
            """
            IGNORE_CASE = TRANSLITERATION_MODULES_NEW_IGNORE_CASE
            """
            Ignore case when comparing strings by transliteration service.
            """
            IGNORE_KANA = TRANSLITERATION_MODULES_NEW_IGNORE_KANA
            """
            Ignore Hiragana and Katakana when comparing strings by transliteration service.
            """
            IGNORE_WIDTH = TRANSLITERATION_MODULES_NEW_IGNORE_WIDTH
            """
            Ignore full width and half width character when comparing strings by transliteration service.

            Ignore full width and half width characters when comparing strings by transliteration service.
            """
            IgnoreBaFa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreBaFa_ja_JP
            """
            Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
            """
            IgnoreHyuByu_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreHyuByu_ja_JP
            """
            Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
            """
            IgnoreIandEfollowedByYa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreIandEfollowedByYa_ja_JP
            """
            Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.

            Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
            """
            IgnoreIterationMark_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreIterationMark_ja_JP
            """
            Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
            """
            IgnoreKiKuFollowedBySa_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreKiKuFollowedBySa_ja_JP
            """
            Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.

            Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
            """
            IgnoreMiddleDot_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreMiddleDot_ja_JP
            """
            Ignore middle dot in Japanese fuzzy search.
            """
            IgnoreMinusSign_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreMinusSign_ja_JP
            """
            Ignore dash or minus sign in Japanese fuzzy search.
            """
            IgnoreProlongedSoundMark_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreProlongedSoundMark_ja_JP
            """
            Ignore Japanese prolonged sound mark in Japanese fuzzy search.
            """
            IgnoreSeZe_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSeZe_ja_JP
            """
            Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
            """
            IgnoreSeparator_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSeparator_ja_JP
            """
            Ignore separator punctuations in Japanese fuzzy search.
            """
            IgnoreSize_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSize_ja_JP
            """
            Ignore Japanese normal and small sized character in Japanese fuzzy search.
            """
            IgnoreSpace_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreSpace_ja_JP
            """
            Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
            """
            IgnoreTiJi_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTiJi_ja_JP
            """
            Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
            """
            IgnoreTraditionalKana_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKana_ja_JP
            """
            Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.

            Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
            """
            IgnoreTraditionalKanji_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreTraditionalKanji_ja_JP
            """
            Ignore Japanese traditional Kanji character in Japanese fuzzy search.

            Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
            """
            IgnoreZiZu_ja_JP = TRANSLITERATION_MODULES_NEW_IgnoreZiZu_ja_JP
            """
            Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
            """
            KATAKANA_HIRAGANA = TRANSLITERATION_MODULES_NEW_KATAKANA_HIRAGANA
            """
            Transliterate a Japanese string from Katakana to Hiragana.
            """
            LOWERCASE_UPPERCASE = TRANSLITERATION_MODULES_NEW_LOWERCASE_UPPERCASE
            """
            Transliterate a string from lower case to upper case.
            """
            LargeToSmall_ja_JP = TRANSLITERATION_MODULES_NEW_LargeToSmall_ja_JP
            """
            transliterate Japanese normal sized character to small sized character
            """
            NumToCharFullwidth = TRANSLITERATION_MODULES_NEW_NumToCharFullwidth
            """
            Transliterate a half width number string to full width number string.
            """
            NumToCharHangul_ko = TRANSLITERATION_MODULES_NEW_NumToCharHangul_ko
            """
            Transliterate an ASCII number string to Korean Hangul number string.
            """
            NumToCharKanjiShort_ja_JP = TRANSLITERATION_MODULES_NEW_NumToCharKanjiShort_ja_JP
            """
            Transliterate an ASCII number string to Japanese Kanji number string.
            """
            NumToCharLower_ko = TRANSLITERATION_MODULES_NEW_NumToCharLower_ko
            """
            Transliterate an ASCII number string to Korean Hanja lower case number string.
            """
            NumToCharLower_zh_CN = TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese lower case number string.
            """
            NumToCharLower_zh_TW = TRANSLITERATION_MODULES_NEW_NumToCharLower_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese lower case number string.
            """
            NumToCharUpper_ko = TRANSLITERATION_MODULES_NEW_NumToCharUpper_ko
            """
            Transliterate an ASCII number string to Korean Hanja upper case number string.
            """
            NumToCharUpper_zh_CN = TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese upper case number string.
            """
            NumToCharUpper_zh_TW = TRANSLITERATION_MODULES_NEW_NumToCharUpper_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese upper case number string.
            """
            NumToTextFormalHangul_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalHangul_ko
            """
            Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
            """
            NumToTextFormalLower_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalLower_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
            """
            NumToTextFormalUpper_ko = TRANSLITERATION_MODULES_NEW_NumToTextFormalUpper_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
            """
            NumToTextInformalHangul_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalHangul_ko
            """
            Transliterate an ASCII number string to informal Korean Hangul number string in spellout format.
            """
            NumToTextInformalLower_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalLower_ko
            """
            Transliterate an ASCII number string to informal Korean Hanja lower case number string in spellout format.
            """
            NumToTextInformalUpper_ko = TRANSLITERATION_MODULES_NEW_NumToTextInformalUpper_ko
            """
            Transliterate an ASCII number string to informal Korean Hanja upper case number string in spellout format.
            """
            NumToTextLower_zh_CN = TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
            """
            NumToTextLower_zh_TW = TRANSLITERATION_MODULES_NEW_NumToTextLower_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
            """
            NumToTextUpper_zh_CN = TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
            """
            NumToTextUpper_zh_TW = TRANSLITERATION_MODULES_NEW_NumToTextUpper_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
            """
            SmallToLarge_ja_JP = TRANSLITERATION_MODULES_NEW_SmallToLarge_ja_JP
            """
            transliterate Japanese small sized character to normal sized character
            """
            TextToNumFormalHangul_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalHangul_ko
            """
            Transliterate a Korean formal Hangul number string (spellout) to ASCII number string.
            """
            TextToNumFormalLower_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalLower_ko
            """
            Transliterate a Korean formal Hanja lower case number string (spellout) to ASCII number string.
            """
            TextToNumFormalUpper_ko = TRANSLITERATION_MODULES_NEW_TextToNumFormalUpper_ko
            """
            Transliterate a Korean formal Hanja upper case number string (spellout) to ASCII number string.
            """
            TextToNumInformalHangul_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalHangul_ko
            """
            Transliterate a Korean informal Hangul number string (spellout) to ASCII number string.
            """
            TextToNumInformalLower_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalLower_ko
            """
            Transliterate a Korean informal Hanja lower case number string (spellout) to ASCII number string.
            """
            TextToNumInformalUpper_ko = TRANSLITERATION_MODULES_NEW_TextToNumInformalUpper_ko
            """
            Transliterate a Korean informal Hanja upper case number string (spellout) to ASCII number string.
            """
            TextToNumLower_zh_CN = TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_CN
            """
            Transliterate a Simplified Chinese lower case number string (spellout) to ASCII number string.
            """
            TextToNumLower_zh_TW = TRANSLITERATION_MODULES_NEW_TextToNumLower_zh_TW
            """
            Transliterate a Traditional Chinese lower case number string (spellout) to ASCII number string.
            """
            TextToNumUpper_zh_CN = TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_CN
            """
            Transliterate a Simplified Chinese upper case number string (spellout) to ASCII number string.
            """
            TextToNumUpper_zh_TW = TRANSLITERATION_MODULES_NEW_TextToNumUpper_zh_TW
            """
            Transliterate a Traditional Chinese upper case number string (spellout) to ASCII number string.
            """
            UPPERCASE_LOWERCASE = TRANSLITERATION_MODULES_NEW_UPPERCASE_LOWERCASE
            """
            Transliterate a string from upper case to lower case.
            """
    else:
        # keep document generators happy
        from ...lo.i18n.transliteration_modules_new import TransliterationModulesNew as TransliterationModulesNew


__all__ = ['TransliterationModulesNew']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xsd


class DataTypeClass(object):
    """
    Const Class

    These constants specify the class used of an XDataType.

    See Also:
        `API DataTypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xsd_1_1DataTypeClass.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xsd'
    __ooo_full_ns__: str = 'com.sun.star.xsd.DataTypeClass'
    __ooo_type_name__: str = 'const'

    STRING = 1
    """
    specifies an XSD compliant string type
    """
    BOOLEAN = 2
    """
    specifies an XSD compliant boolean type
    """
    DECIMAL = 3
    """
    specifies an XSD compliant decimal type
    """
    FLOAT = 4
    """
    specifies an XSD compliant float type
    """
    DOUBLE = 5
    """
    specifies an XSD compliant double type
    """
    DURATION = 6
    """
    specifies an XSD compliant duration type
    """
    DATETIME = 7
    """
    specifies an XSD compliant datetime type
    """
    TIME = 8
    """
    specifies an XSD compliant time type
    """
    DATE = 9
    """
    specifies an XSD compliant date type
    """
    gYearMonth = 10
    """
    specifies an XSD compliant gYearMonth type
    """
    gYear = 11
    """
    specifies an XSD compliant gYear type
    """
    gMonthDay = 12
    """
    specifies an XSD compliant gMonthDay type
    """
    gDay = 13
    """
    specifies an XSD compliant gDay type
    """
    gMonth = 14
    """
    specifies an XSD compliant gMonth type
    """
    hexBinary = 15
    """
    specifies an XSD compliant hexBinary type
    """
    base64Binary = 16
    """
    specifies an XSD compliant base64Binary type
    """
    anyURI = 17
    """
    specifies an XSD compliant anyURI type
    """
    QName = 18
    """
    specifies an XSD compliant QName type
    """
    NOTATION = 19
    """
    specifies an XSD compliant NOTATION type
    """

__all__ = ['DataTypeClass']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class XSQLQueryComposer(XInterface_8f010a43):
    """
    should be provided by a tool which simplifies the handling with SQL select statements.
    
    The interface can be used for composing SELECT statements without knowing the structure of the used query.

    See Also:
        `API XSQLQueryComposer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XSQLQueryComposer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XSQLQueryComposer'

    @abstractmethod
    def appendFilterByColumn(self, column: XPropertySet_bc180bfa) -> None:
        """
        appends a new filter condition by a com.sun.star.sdb.DataColumn providing the name and the value for the filter.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def appendOrderByColumn(self, column: XPropertySet_bc180bfa, ascending: bool) -> None:
        """
        appends an additional part to the sort order criteria of the select statement.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getComposedQuery(self) -> str:
        """
        returns the query composed with filters and sort criteria.
        """
        ...
    @abstractmethod
    def getFilter(self) -> str:
        """
        returns the currently used filter.
        
        The filter criteria returned is part of the where condition of the select command, but it does not contain the where token.
        """
        ...
    @abstractmethod
    def getOrder(self) -> str:
        """
        returns the currently used sort order.
        
        The order criteria returned is part of the ORDER BY clause of the select command, but it does not contain the ORDER BY keyword .
        """
        ...
    @abstractmethod
    def getQuery(self) -> str:
        """
        returns the query used for composing.
        """
        ...
    @abstractmethod
    def getStructuredFilter(self) -> typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]:
        """
        returns the currently used filter.
        
        The filter criteria is split into levels. Each level represents the OR criteria. Within each level, the filters are provided as an AND criteria with the name of the column and the filter condition. The filter condition is of type string.
        """
        ...
    @abstractmethod
    def setFilter(self, filter: str) -> None:
        """
        makes it possible to set a filter condition for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def setOrder(self, order: str) -> None:
        """
        makes it possible to set a sort condition for the query.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def setQuery(self, command: str) -> None:
        """
        sets a new query for the composer, which may be expanded by filters and sort criteria.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XSQLQueryComposer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.lang
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Locale(object):
    """
    Struct Class

    object represents a specific geographical, political, or cultural region.
    
    An operation that requires a Locale to perform its task is called locale-sensitive and uses the Locale to tailor information for the user. For example, displaying a number is a locale-sensitive operation; the number should be formatted according to the customs/conventions of the user's native country, region, or culture.

    See Also:
        `API Locale <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1lang_1_1Locale.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.Locale'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.lang.Locale'
    """Literal Constant ``com.sun.star.lang.Locale``"""

    def __init__(self, Language: typing.Optional[str] = '', Country: typing.Optional[str] = '', Variant: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Language (str, optional): Language value.
            Country (str, optional): Country value.
            Variant (str, optional): Variant value.
        """
        super().__init__()

        if isinstance(Language, Locale):
            oth: Locale = Language
            self.Language = oth.Language
            self.Country = oth.Country
            self.Variant = oth.Variant
            return

        kargs = {
            "Language": Language,
            "Country": Country,
            "Variant": Variant,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._language = kwargs["Language"]
        self._country = kwargs["Country"]
        self._variant = kwargs["Variant"]


    @property
    def Language(self) -> str:
        """
        specifies an ISO 639 Language Code.
        
        These codes are preferably the lower-case two-letter codes as defined by ISO 639-1, or three-letter codes as defined by ISO 639-3. You can find a full list of these codes at a number of sites, such as: https://iso639-3.sil.org/code_tables/639/data.
        
        If this field contains an empty string, the meaning depends on the context.
        
        Since LibreOffice 4.2, if the locale can not be represented using only ISO 639 and ISO 3166 codes this field contains the ISO 639-3 reserved for local use code \"qlt\" and a BCP 47 language tag is present in the Variant field.
        """
        return self._language

    @Language.setter
    def Language(self, value: str) -> None:
        self._language = value

    @property
    def Country(self) -> str:
        """
        specifies an ISO 3166 Country Code.
        
        These codes are the upper-case two-letter codes as defined by ISO 3166-1. You can find a full list of these codes at a number of sites, such as: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2.
        
        If this field contains an empty string, the meaning depends on the context.
        """
        return self._country

    @Country.setter
    def Country(self, value: str) -> None:
        self._country = value

    @property
    def Variant(self) -> str:
        """
        specifies a BCP 47 Language Tag.
        
        Since LibreOffice 4.2, if the Language field is the code \"qlt\" this field contains the full BCP 47 language tag. If the Language field is not \"qlt\" this field is empty.
        
        You can find BCP 47 language tag resources at https://en.wikipedia.org/wiki/IETF_language_tag and https://www.w3.org/International/articles/language-tags/.
        
        Earlier versions of the documentation mentioned \"vendor andbrowser-specific\" codes but that was never supported. Use of any arbitrary strings in the Variant field that do not form a valid BCP 47 language tag is strongly deprecated.
        """
        return self._variant

    @Variant.setter
    def Variant(self, value: str) -> None:
        self._variant = value


__all__ = ['Locale']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractmethod
from .x_command_processor import XCommandProcessor as XCommandProcessor_dfe80d19

class XCommandProcessor2(XCommandProcessor_dfe80d19):
    """
    An improved version of a com.sun.star.ucb.XCommandProcessor that helps avoid ever-increasing resource consumption.

    See Also:
        `API XCommandProcessor2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XCommandProcessor2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XCommandProcessor2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XCommandProcessor2'

    @abstractmethod
    def releaseCommandIdentifier(self, CommandId: int) -> None:
        """
        releases a command identifier obtained through XCommandProcessor.createCommandIdentifier() when it is no longer used.
        
        After this call the command identifier cannot be used any longer in calls to XCommandProcessor.execute() and XCommandProcessor.abort(). (But it can happen that a call to XCommandProcessor.createCommandIdentifier() reuses this identifier.)
        """
        ...

__all__ = ['XCommandProcessor2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_info_printer import XInfoPrinter as XInfoPrinter_a3fd0b1c
    from .x_printer import XPrinter as XPrinter_7ad00990

class XPrinterServer(XInterface_8f010a43):
    """
    manages several printers on one machine.

    See Also:
        `API XPrinterServer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XPrinterServer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XPrinterServer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XPrinterServer'

    @abstractmethod
    def createInfoPrinter(self, printerName: str) -> XInfoPrinter_a3fd0b1c:
        """
        creates a new information printer.
        
        You can get all information from this printer, but the printer cannot really print.
        """
        ...
    @abstractmethod
    def createPrinter(self, printerName: str) -> XPrinter_7ad00990:
        """
        creates a new virtual printer.
        
        You must call com.sun.star.awt.XPrinter.start() to put the job into the printer spooler.
        """
        ...
    @abstractmethod
    def getPrinterNames(self) -> typing.Tuple[str, ...]:
        """
        returns a list of all available printer names.
        """
        ...

__all__ = ['XPrinterServer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..accessibility.x_accessible import XAccessible as XAccessible_1cbc0eb6
    from ..awt.x_window import XWindow as XWindow_713b0924

class XToolPanel(ABC):
    """
    describes the basic interface to be implemented by a tool panel

    See Also:
        `API XToolPanel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XToolPanel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XToolPanel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XToolPanel'

    @abstractmethod
    def createAccessible(self, ParentAccessible: XAccessible_1cbc0eb6) -> XAccessible_1cbc0eb6:
        """
        creates the root of the Accessibility object tree for the tool panel
        """
        ...
    @abstractproperty
    def Window(self) -> XWindow_713b0924:
        """
        provides access to the tool panel's main window.
        
        It is allowed for an implementation to return NULL here, but in this case some functionality, for instance automatic positioning of the tool panel, might not be available, and must be implemented by the tool panel itself.
        """
        ...


__all__ = ['XToolPanel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..awt.point import Point as Point_5fb2085e


class BezierPoint(object):
    """
    Struct Class

    This is a point on a Bezier curve.
    
    The two control points specify how the Bezier curve goes through the given position.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API BezierPoint <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1BezierPoint.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.BezierPoint'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.BezierPoint'
    """Literal Constant ``com.sun.star.drawing.BezierPoint``"""

    def __init__(self, Position: typing.Optional[Point_5fb2085e] = UNO_NONE, ControlPoint1: typing.Optional[Point_5fb2085e] = UNO_NONE, ControlPoint2: typing.Optional[Point_5fb2085e] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            Position (Point, optional): Position value.
            ControlPoint1 (Point, optional): ControlPoint1 value.
            ControlPoint2 (Point, optional): ControlPoint2 value.
        """
        super().__init__()

        if isinstance(Position, BezierPoint):
            oth: BezierPoint = Position
            self.Position = oth.Position
            self.ControlPoint1 = oth.ControlPoint1
            self.ControlPoint2 = oth.ControlPoint2
            return

        kargs = {
            "Position": Position,
            "ControlPoint1": ControlPoint1,
            "ControlPoint2": ControlPoint2,
        }
        if kargs["Position"] is UNO_NONE:
            kargs["Position"] = None
        if kargs["ControlPoint1"] is UNO_NONE:
            kargs["ControlPoint1"] = None
        if kargs["ControlPoint2"] is UNO_NONE:
            kargs["ControlPoint2"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._control_point1 = kwargs["ControlPoint1"]
        self._control_point2 = kwargs["ControlPoint2"]


    @property
    def Position(self) -> Point_5fb2085e:
        """
        This is the position of this point.
        """
        return self._position

    @Position.setter
    def Position(self, value: Point_5fb2085e) -> None:
        self._position = value

    @property
    def ControlPoint1(self) -> Point_5fb2085e:
        """
        This is the position of the first control point.
        """
        return self._control_point1

    @ControlPoint1.setter
    def ControlPoint1(self, value: Point_5fb2085e) -> None:
        self._control_point1 = value

    @property
    def ControlPoint2(self) -> Point_5fb2085e:
        """
        This is the position of the second control point.
        """
        return self._control_point2

    @ControlPoint2.setter
    def ControlPoint2(self, value: Point_5fb2085e) -> None:
        self._control_point2 = value


__all__ = ['BezierPoint']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..lang.locale import Locale as Locale_70d308fa
from .table_sort_field_type import TableSortFieldType as TableSortFieldType_9a50e26


class TableSortField(object):
    """
    Struct Class

    describes how to sort a single field (row/column) in a tables sort descriptor.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TableSortField <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1TableSortField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.TableSortField'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.TableSortField'
    """Literal Constant ``com.sun.star.table.TableSortField``"""

    def __init__(self, Field: typing.Optional[int] = 0, IsAscending: typing.Optional[bool] = False, IsCaseSensitive: typing.Optional[bool] = False, FieldType: typing.Optional[TableSortFieldType_9a50e26] = TableSortFieldType_9a50e26.AUTOMATIC, CollatorLocale: typing.Optional[Locale_70d308fa] = UNO_NONE, CollatorAlgorithm: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Field (int, optional): Field value.
            IsAscending (bool, optional): IsAscending value.
            IsCaseSensitive (bool, optional): IsCaseSensitive value.
            FieldType (TableSortFieldType, optional): FieldType value.
            CollatorLocale (Locale, optional): CollatorLocale value.
            CollatorAlgorithm (str, optional): CollatorAlgorithm value.
        """
        super().__init__()

        if isinstance(Field, TableSortField):
            oth: TableSortField = Field
            self.Field = oth.Field
            self.IsAscending = oth.IsAscending
            self.IsCaseSensitive = oth.IsCaseSensitive
            self.FieldType = oth.FieldType
            self.CollatorLocale = oth.CollatorLocale
            self.CollatorAlgorithm = oth.CollatorAlgorithm
            return

        kargs = {
            "Field": Field,
            "IsAscending": IsAscending,
            "IsCaseSensitive": IsCaseSensitive,
            "FieldType": FieldType,
            "CollatorLocale": CollatorLocale,
            "CollatorAlgorithm": CollatorAlgorithm,
        }
        if kargs["CollatorLocale"] is UNO_NONE:
            kargs["CollatorLocale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._field = kwargs["Field"]
        self._is_ascending = kwargs["IsAscending"]
        self._is_case_sensitive = kwargs["IsCaseSensitive"]
        self._field_type = kwargs["FieldType"]
        self._collator_locale = kwargs["CollatorLocale"]
        self._collator_algorithm = kwargs["CollatorAlgorithm"]


    @property
    def Field(self) -> int:
        """
        index of the row or column in the table to be sorted; 0-based.
        """
        return self._field

    @Field.setter
    def Field(self, value: int) -> None:
        self._field = value

    @property
    def IsAscending(self) -> bool:
        """
        TRUE if data are sorted in ascending order, FALSE if in descending order.
        """
        return self._is_ascending

    @IsAscending.setter
    def IsAscending(self, value: bool) -> None:
        self._is_ascending = value

    @property
    def IsCaseSensitive(self) -> bool:
        """
        specifies if the case of letters is important when comparing entries.
        """
        return self._is_case_sensitive

    @IsCaseSensitive.setter
    def IsCaseSensitive(self, value: bool) -> None:
        self._is_case_sensitive = value

    @property
    def FieldType(self) -> TableSortFieldType_9a50e26:
        """
        type of contents in the field.
        
        If the value is com.sun.star.table.TableSortFieldType.AUTOMATIC the algorithm used for sorting is application specific. Especially it may or may not use the values given by \"CollatorLocale\" and \"CollatorAlgorithm\".
        """
        return self._field_type

    @FieldType.setter
    def FieldType(self, value: TableSortFieldType_9a50e26) -> None:
        self._field_type = value

    @property
    def CollatorLocale(self) -> Locale_70d308fa:
        """
        the locale used by the collator when comparing/sorting text.
        
        This property will not be used when the \"FieldType\" is com.sun.star.table.TableSortFieldType.NUMERIC
        """
        return self._collator_locale

    @CollatorLocale.setter
    def CollatorLocale(self, value: Locale_70d308fa) -> None:
        self._collator_locale = value

    @property
    def CollatorAlgorithm(self) -> str:
        """
        the algorithm used by the collator when comparing/sorting text.
        
        This property will not be used when the \"FieldType\" is com.sun.star.table.TableSortFieldType.NUMERIC
        """
        return self._collator_algorithm

    @CollatorAlgorithm.setter
    def CollatorAlgorithm(self, value: str) -> None:
        self._collator_algorithm = value


__all__ = ['TableSortField']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TextHorizontalAdjust(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.TextHorizontalAdjust", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.TextHorizontalAdjust`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.TextHorizontalAdjust import BLOCK as TEXT_HORIZONTAL_ADJUST_BLOCK
        from com.sun.star.drawing.TextHorizontalAdjust import CENTER as TEXT_HORIZONTAL_ADJUST_CENTER
        from com.sun.star.drawing.TextHorizontalAdjust import LEFT as TEXT_HORIZONTAL_ADJUST_LEFT
        from com.sun.star.drawing.TextHorizontalAdjust import RIGHT as TEXT_HORIZONTAL_ADJUST_RIGHT

        class TextHorizontalAdjust(uno.Enum):
            """
            Enum Class


            See Also:
                `API TextHorizontalAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.TextHorizontalAdjust', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.TextHorizontalAdjust'
            __ooo_type_name__: str = 'enum'

            BLOCK = TEXT_HORIZONTAL_ADJUST_BLOCK
            """
            The text extends from the left to the right edge of the shape.

            The text extends from the top to the bottom edge of the shape.
            """
            CENTER = TEXT_HORIZONTAL_ADJUST_CENTER
            """
            The text is centered inside the shape.
            """
            LEFT = TEXT_HORIZONTAL_ADJUST_LEFT
            """
            the connection line leaves the connected object to the left,

            The left edge of the text is adjusted to the left edge of the shape.

            The text is positioned to the left.
            """
            RIGHT = TEXT_HORIZONTAL_ADJUST_RIGHT
            """
            the connection line leaves the connected object to the right,

            The right edge of the text is adjusted to the right edge of the shape.

            The text is positioned to the right.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.text_horizontal_adjust import TextHorizontalAdjust as TextHorizontalAdjust


__all__ = ['TextHorizontalAdjust']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
from abc import abstractproperty
from ..text_field import TextField as TextField_90260a56

class URL(TextField_90260a56):
    """
    Service Class

    specifies service of text field that displays a URL

    See Also:
        `API URL <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1URL.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.URL'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Format(self) -> int:
        """
        Specifies how the URL is formatted on output.
        """
        ...

    @abstractproperty
    def Representation(self) -> str:
        """
        contains the content that will be displayed to the user.
        
        If this string is empty, the URL will be shown.
        """
        ...

    @abstractproperty
    def TargetFrame(self) -> str:
        """
        Specifies the frame name in that the URL will be opened.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        contains the unparsed original URL, for example, http://me:pass@www.sun.de:8080/pub/test/foo.txt?a=b#xyz
        """
        ...


__all__ = ['URL']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.accessibility
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class AccessibleEventObject(EventObject_a3d70b03):
    """
    Struct Class

    this struct describes an accessible event, that is broadcasted from the XAccessibleEventBroadcaster and notified to XAccessibleEventListener.
    
    It is usually implemented by AccessibleContext.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleEventObject <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1accessibility_1_1AccessibleEventObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.AccessibleEventObject'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.accessibility.AccessibleEventObject'
    """Literal Constant ``com.sun.star.accessibility.AccessibleEventObject``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, EventId: typing.Optional[int] = 0, NewValue: typing.Optional[object] = None, OldValue: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            EventId (int, optional): EventId value.
            NewValue (object, optional): NewValue value.
            OldValue (object, optional): OldValue value.
        """

        if isinstance(Source, AccessibleEventObject):
            oth: AccessibleEventObject = Source
            self.Source = oth.Source
            self.EventId = oth.EventId
            self.NewValue = oth.NewValue
            self.OldValue = oth.OldValue
            return

        kargs = {
            "Source": Source,
            "EventId": EventId,
            "NewValue": NewValue,
            "OldValue": OldValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._event_id = kwargs["EventId"]
        self._new_value = kwargs["NewValue"]
        self._old_value = kwargs["OldValue"]
        inst_keys = ('EventId', 'NewValue', 'OldValue')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def EventId(self) -> int:
        """
        specifies the type of this event.
        
        For a list of possible events see AccessibleEventId.
        """
        return self._event_id

    @EventId.setter
    def EventId(self, value: int) -> None:
        self._event_id = value

    @property
    def NewValue(self) -> object:
        """
        for events that specifies a value change, this is the new value.
        
        Depending on the EventId, this can be void.
        """
        return self._new_value

    @NewValue.setter
    def NewValue(self, value: object) -> None:
        self._new_value = value

    @property
    def OldValue(self) -> object:
        """
        for events that specifies a value change, this is the old value.
        
        Depending on the EventId, this can be void.
        """
        return self._old_value

    @OldValue.setter
    def OldValue(self, value: object) -> None:
        self._old_value = value


__all__ = ['AccessibleEventObject']
